import { useState, useLayoutEffect, useCallback } from 'react';
import useMountedState from '../useMountedState';
/**
 * React hook for combine the state of a value prop and its default value
 **/

var useControlledState = function useControlledState(controlledValue, defaultValue) {
  var _useState = useState(controlledValue === undefined ? defaultValue : controlledValue),
      initialValue = _useState[0];

  var _useState2 = useState(initialValue),
      value = _useState2[0],
      setValue = _useState2[1];

  var isMounted = useMountedState();
  useLayoutEffect(function () {
    if (isMounted()) {
      setValue(controlledValue);
    }
  }, [controlledValue, setValue, isMounted]);
  var updater = useCallback(function (value, forceFlag) {
    if (controlledValue === undefined || forceFlag) {
      setValue(value);
    }
  }, [controlledValue, setValue]);
  return [value, updater, controlledValue !== undefined, initialValue];
};

export default useControlledState;